/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "StatisticsWiiU.h"
#include <wtf/StdLibExtras.h>

void ** g_StaticLocals[2048] = {0};
unsigned int g_StaticLocalCount = 0;

namespace WTF {

// Global instance of the performance logger.
StatisticsWiiU *StatisticsWiiU::m_instance = NULL;

// See comments in StatisticsWiiU.h

StatisticsWiiU::StatisticsWiiU() {
	m_paintCount = 0;
	m_imageCount = 0;
	m_fontCacheCount = 0;
	m_transLayerCount = 0; 
	m_imageBufferCount = 0;
}

void StatisticsWiiU::clearPaintCount() {
	m_paintCount = 0; 
} 

void StatisticsWiiU::clearImageCount() {
	m_imageCount = 0; 
} 

void StatisticsWiiU::clearFontCacheCount() {
	m_fontCacheCount = 0; 
}

void StatisticsWiiU::clearTransparencyLayerCount() {
	m_transLayerCount = 0; 
}

void StatisticsWiiU::clearImageBufferCount() {
	m_imageBufferCount = 0;
} 

void StatisticsWiiU::clearAll() {
	clearPaintCount(); 
	clearImageCount();
	clearFontCacheCount(); 
	clearTransparencyLayerCount(); 
	clearImageBufferCount(); 
}
		
unsigned StatisticsWiiU::getPaintCount() {
	return m_paintCount; 
}

unsigned StatisticsWiiU::getImageCount() {
	return m_imageCount;
} 

unsigned StatisticsWiiU::getFontCacheCount() {
	return m_fontCacheCount; 
} 

unsigned StatisticsWiiU::getTransparencyLayerCount() {
	return m_transLayerCount;
} 

unsigned StatisticsWiiU::getImageBufferCount() {
	return m_imageBufferCount; 
} 
		
StatisticsWiiU *StatisticsWiiU::instance() {
	if(m_instance == NULL) {
		m_instance = new StatisticsWiiU();
		ADD_TO_STATIC_LOCAL(m_instance);
	}
	return m_instance; 
}

} //Namespace closure